BorrowedFd

Struct BorrowedFd 

1.66.0 · Source
#[repr(transparent)]
pub struct BorrowedFd<'fd> { fd: NotAllOnes<RawFd>, _phantom: PhantomData<&'fd OwnedFd>, }
Available on Hermit or Motor OS or Trusty or Unix or WASI only.
A borrowed file descriptor.

This has a lifetime parameter to tie it to the lifetime of something that owns the file descriptor. For the duration of that lifetime, it is guaranteed that nobody will close the file descriptor.

This uses repr(transparent) and has the representation of a host file descriptor, so it can be used in FFI in places where a file descriptor is passed as an argument, it is not captured or consumed, and it never has the value -1.

This type does not have a ToOwned implementation. Calling .to_owned() on a variable of this type will call it on &BorrowedFd and use Clone::clone() like ToOwned does for all types implementing Clone. The result will be descriptor borrowed under the same lifetime.

To obtain an OwnedFd, you can use BorrowedFd::try_clone_to_owned instead, but this is not supported on all platforms.

Fields

fd: NotAllOnes<RawFd>_phantom: PhantomData<&'fd OwnedFd>

Implementations

Source

impl BorrowedFd<'_>

1.63.0 (const: 1.63.0) · Source

pub const unsafe fn borrow_raw(fd: RawFd) -> Self

Returns a BorrowedFd holding the given raw file descriptor.

Safety

The resource pointed to by fd must remain open for the duration of the returned BorrowedFd.

Panics

Panics if the raw file descriptor has the value -1.

Source

impl BorrowedFd<'_>

1.63.0 · Source

pub fn try_clone_to_owned(&self) -> Result<OwnedFd>

Available on neither Hermit, nor Motor OS, nor Trusty, nor WebAssembly and non-Emscripten.

Creates a new OwnedFd instance that shares the same underlying file description as the existing BorrowedFd instance.